# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2016-10-05 19:08
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djreservation', '0005_reservationtoken'),
    ]

    operations = [
        migrations.AddField(
            model_name='reservationtoken',
            name='base_url',
            field=models.URLField(default='http://localhost:8000'),
        ),
    ]
