{% extends 'base.html' %}
{% load i18n %}

{% block content %}
	<div class="row">
		 <div class="col-md-6 col-md-offset-3">
	{% trans 'Thanks, your reservation was processed successfully' %}
		</div>
	</div>
{% endblock %}
