# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2016-10-05 17:37
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('djreservation', '0004_auto_20161005_0022'),
    ]

    operations = [
        migrations.CreateModel(
            name='ReservationToken',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('token', models.UUIDField(default=uuid.uuid4, editable=False)),
                ('reservation', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djreservation.Reservation')),
            ],
        ),
    ]
