# Generated by Django 2.1.7 on 2019-02-20 03:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djreservation', '0006_reservationtoken_base_url'),
    ]

    operations = [
        migrations.AlterField(
            model_name='reservation',
            name='status',
            field=models.SmallIntegerField(choices=[(0, 'Building'), (1, 'Requested'), (2, 'Accepted'), (3, 'Denied'), (4, 'Borrowed'), (5, 'Returned')], default=0),
        ),
    ]
