# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2016-10-05 06:22
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djreservation', '0003_auto_20161004_1525'),
    ]

    operations = [
        migrations.RenameField(
            model_name='reservation',
            old_name='return_date',
            new_name='reserved_end_date',
        ),
    ]
